@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.089-6-gacd0495
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.090-7-ge8007de
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.090';
+our $VERSION = '0.091';
 
 use Moose;
 with
@@ -14,7 +14,7 @@ with
     'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
 use Dist::Zilla::Util;
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints qw(enum subtype where);
 use List::Util 1.33 qw(first any);
 use List::MoreUtils 'uniq';
 use Module::Runtime 'require_module';
@@ -103,7 +103,10 @@ my %network_plugins;
 my $has_bash = can_run('bash');
 
 # files that might be in the repository that should never be gathered
-my @never_gather = qw(Makefile.PL README.md README.pod META.json cpanfile TODO CONTRIBUTING LICENSE);
+my @never_gather = qw(
+    Makefile.PL ppport.h README.md README.pod META.json
+    cpanfile TODO CONTRIBUTING LICENSE inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
+);
 
 around BUILDARGS => sub
 {
@@ -133,6 +136,9 @@ sub configure
     warn '[@Author::ETHER] ' . colored('bin/ detected - should this be moved to script/, so its contents can be installed into $PATH?', 'bright_red') . "\n"
         if -d 'bin' and any { $_ eq 'ModuleBuildTiny' } $self->installer;
 
+    my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
+    my %removed; @removed{@$remove} = (!!1) x @$remove;
+
     my @plugins = (
         # VersionProvider
         [ 'RewriteVersion::Transitional' => { ':version' => '0.004', fallback_version_provider => 'Git::NextVersion', version_regexp => '^v([\d._]+)(-TRIAL)?$',
@@ -177,7 +183,9 @@ sub configure
         'Test::Pod::No404s',
         [ 'Test::Kwalitee'      => { ':version' => '2.06' } ],
         'MojibakeTests',
-        [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1 } ],
+        [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1,
+            exists $removed{PodCoverageTests} ? () : ( include => [ 'Pod::Coverage' ] ),
+          } ],
         'Test::Portability',
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
@@ -300,13 +308,10 @@ sub configure
         'ConfirmRelease',
     );
 
-    my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
-    my %remove; @remove{@$remove} = (!!1) x @$remove;
-
     my $plugin_requirements = CPAN::Meta::Requirements->new;
     foreach my $plugin_spec (@plugins = map { ref $_ ? $_ : [ $_ ] } @plugins)
     {
-        next if $remove{$plugin_spec->[0]};
+        next if $removed{$plugin_spec->[0]};
 
         my $plugin = Dist::Zilla::Util->expand_config_package_name($plugin_spec->[0]);
         require_module($plugin);
@@ -366,7 +371,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.090
+version 0.091
 
 =head1 SYNOPSIS
 
@@ -415,10 +420,16 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ;;; Gather Files
     [Git::GatherDir]
     :version = 2.016
+    exclude_filename = Makefile.PL
+    exclude_filename = ppport.h
     exclude_filename = README.md
     exclude_filename = README.pod
-    exclude_filename = LICENSE
+    exclude_filename = META.json
+    exclude_filename = cpanfile
+    exclude_filename = TODO
     exclude_filename = CONTRIBUTING
+    exclude_filename = LICENSE
+    exclude_filename = inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
 
     [MetaYAML]
     [MetaJSON]
@@ -465,6 +476,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Test::ReportPrereqs]
     :version = 0.019
     verify_prereqs = 1
+    include = Pod::Coverage
     [Test::Portability]
 
 
